from setuptools import setup

setup(
    name="zq_logger",
    version="0.4",
    author="zzqq2199",
    author_email="zhouquanjs@qq.com",
    description="customized logger",
    url='http://www.google.com/search?q=zq_logger',
    packages=['zq_logger'],
    install_requires=['colorlog==5.0.1']
)